package ao.tool;

import java.io.File;
import java.io.FileInputStream;

public class TestCallLSRestAPIV5 {

	//set RestAPI URL
	private static String LSRestAPIURL = "";
	private static String APIKey = "";
	private static String DomainCode = "";
	private static String ProjectNo = "";
	private static String AdvancedSettingsXML = "";
	
	public static void main(String[] args) {
		
		String Method = "", INIData = "", DataToProcess = "";
		try {
						
			if(args.length<4) throw new Exception("Invalid parameter.");
			
			//arg:
			//1. Method
			//2. INI Path
			//3. DataToProcess	
			//4. DomainCode
			//5. AdvancedSettingsXML //optional
			//6. ProjectNo //optional
			Method = ChkNullStrObj(args[0]).toUpperCase();
			INIData = readFile(ChkNullStrObj(args[1]));
			DataToProcess = ChkNullStrObj(args[2]);
			DomainCode = ChkNullStrObj(args[3]);
			if(args.length>=5) AdvancedSettingsXML = ChkNullStrObj(args[4]);
			if(args.length>=6) ProjectNo = ChkNullStrObj(args[5]);
			
			//Load config data
			readINI(INIData);
			
			if(Method.equals("SUBMIT.TRANSLATE.BATCH")){	
				//Submission of a single/multiple file in Batch mode
				System.out.println("Job.Submit.Translate:Submission of a single/multiple jobs in Batch mode");
				JobSubmitTranslate(APIKey, DomainCode, DataToProcess, ProjectNo, AdvancedSettingsXML);
			}
			else if(Method.equals("SUBMIT.TRANSLATE.REALTIME")){	
				//Submission of phrase in RealTime
				System.out.println("Job.Submit.Translate:Submission of text in RealTime mode");
				JobSubmitTranslateRealTime(APIKey, DomainCode, DataToProcess, ProjectNo, AdvancedSettingsXML);
			}
			
		} catch (Exception e) {
			System.out.println("Error:" + e.getMessage());
		}
	}
		
	private static void JobSubmitTranslate(String APIKey, String DomainCode, String DataToProcess, String ProjectNo, String AdvancedSettingsXML) throws Exception {
	    org.apache.http.client.HttpClient client = new org.apache.http.impl.client.DefaultHttpClient();
	    org.apache.http.client.methods.HttpPost post = new org.apache.http.client.methods.HttpPost(LSRestAPIURL);
	    org.apache.http.entity.mime.MultipartEntity entity = new org.apache.http.entity.mime.MultipartEntity();
	    java.nio.charset.Charset chars = java.nio.charset.Charset.forName("UTF-8");
	 
	    // Set normal parameter
	    org.apache.http.entity.mime.content.StringBody param1 = new org.apache.http.entity.mime.content.StringBody("Job.Submit.Translate", chars);
	    entity.addPart("requesttype", param1);
	 
	    org.apache.http.entity.mime.content.StringBody param2 = new org.apache.http.entity.mime.content.StringBody(APIKey, chars);
	    entity.addPart("apikey", param2);
	             
	    org.apache.http.entity.mime.content.StringBody param3 = new org.apache.http.entity.mime.content.StringBody(DomainCode, chars);
	    entity.addPart("domaincode", param3);                        

		org.apache.http.entity.mime.content.StringBody param4 = new org.apache.http.entity.mime.content.StringBody(ProjectNo, chars);
		entity.addPart("projectno", param4);
		
		org.apache.http.entity.mime.content.StringBody param5 = new org.apache.http.entity.mime.content.StringBody(AdvancedSettingsXML, chars);
		entity.addPart("advancedsettingsxml", param5);
		
		if (AdvancedSettingsXML != null && AdvancedSettingsXML.trim().length() > 0 && AdvancedSettingsXML.trim().toLowerCase().contains("<datatype>2</datatype>")) {
			// For DataType=2-Text string
			org.apache.http.entity.mime.content.StringBody param6 = new org.apache.http.entity.mime.content.StringBody(DataToProcess, chars);
			entity.addPart("datatoprocess", param6);	
		} else {
			// For DataType=1-File
		    String[] Files = DataToProcess.split("[|]");
		    for (String sFilePath : Files) {
		        java.io.File oFile = new java.io.File(sFilePath);
		        if (oFile.exists()) {
		            entity.addPart("file", new org.apache.http.entity.mime.content.FileBody(oFile));
		        }
		    }			
		}
	 
	    // Set entity           
	    post.setEntity(entity);
	     
	    // Post parameters to a server
	    org.apache.http.HttpResponse response = client.execute(post);
	             
	    // Get response text
	    org.apache.http.HttpEntity entityRes = response.getEntity();
	    String returnValue = org.apache.http.util.EntityUtils.toString(entityRes, "UTF-8");
	    System.out.println("Output=" + returnValue.trim());
	}
	
	private static void JobSubmitTranslateRealTime(String APIKey, String DomainCode, String DataToProcess, String ProjectNo, String AdvancedSettingsXML) throws Exception  {
	    // set parameters
	    String sParameters = "requesttype=Job.Submit.Translate&apikey=" + java.net.URLEncoder.encode(APIKey, "UTF-8") 
	    + "&domaincode=" + java.net.URLEncoder.encode(DomainCode, "UTF-8") + "&datatoprocess=" + java.net.URLEncoder.encode(DataToProcess, "UTF-8") 
	    + "&advancedsettingsxml=" + java.net.URLEncoder.encode(AdvancedSettingsXML, "UTF-8");
	    //call RestAPI and receive output
	    String returnValue = HttpPost(LSRestAPIURL, sParameters);
	    System.out.println("Output=" + returnValue.trim());
	}

	private static String HttpPost(String webUrl, String parameters) throws Exception {
	    StringBuilder output = new StringBuilder();
	    java.io.OutputStreamWriter writer = null;
	    java.io.BufferedReader reader = null;
	    java.io.InputStreamReader isReader = null;
	    try {
	        // Send data
	    	java.net.URL url = new java.net.URL(webUrl);
	    	java.net.URLConnection conn = url.openConnection();
	        conn.setDoOutput(true);
	        writer = new java.io.OutputStreamWriter(conn.getOutputStream());
	        writer.write(parameters);
	        writer.flush();
	        // Get the response
	        isReader = new java.io.InputStreamReader(conn.getInputStream(), "UTF-8");
	        reader = new java.io.BufferedReader(isReader);
	        String line;
	        while ((line = reader.readLine()) != null) {
	            output.append(line);
	        }
	        if (reader != null) { reader.close(); }
	        if (isReader != null) { isReader.close();}
	        if (writer != null) { writer.close();}       
	    } catch (Exception e) {
	        e.printStackTrace();
	    } finally {
	        if (reader != null) { reader.close(); }
	        if (isReader != null) { isReader.close();}
	        if (writer != null) { writer.close();}
	    }
	    return output.toString();
	}
	
	private static void readINI(String INIData) throws Exception {
	    
	    try{
	    	if(INIData.trim().length()==0) return ;
	    	
	        //Clean the INI
	    	INIData = INIData.replace("\r\n", "\n");
	    	INIData = INIData.replaceAll("(^|\n)([ ]+)", "$1");
	    	INIData = INIData.replaceAll("([ ]+)($|\n)", "$2");
	    	INIData = INIData.replaceAll("(=[ ]+|[ ]+=)", "=");
	    	INIData = INIData.replaceAll("(\n{2,})", "\n");

	        //Load variables from the INI
        	String[] aLine = INIData.split("\n");
        	for (String line : aLine){
        		if (line.toLowerCase().startsWith("restapiurl="))
        			LSRestAPIURL = Arr(line.split("="),1);     
        		if (line.toLowerCase().startsWith("restapikey="))
        			APIKey = Arr(line.split("="),1);    
        	}
	    }
	    catch (Exception ex){
	    	ex.printStackTrace();
	    	throw ex;
	    }
	}

	public static String readFile(String filePath) {
		String data = "";

		try {
			File file = new File(filePath);
			FileInputStream fin = new FileInputStream(file);
			byte fileContent[] = new byte[(int) file.length()];
			fin.read(fileContent);
			data = new String(fileContent);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return data.replace("﻿", "");

	}

	private static String ChkNullStrObj(Object obj) {
		try {
			if (obj == null)
				return "";
			else
				return obj.toString();
		} catch (Exception ex) {
			return "";
		}
	}

	private static String Arr(String[] obj, int i) {
		try {
			if (obj == null)
				return "";
			else
				return obj[i];
		} catch (Exception ex) {
			return "";
		}
	}
}
